@@ -1,18 +1,18 @@
 # To check the convergency of the BDMCMC algorithm
-plotcoda = function( x, thin = NULL, main = NULL, links = TRUE, ... )
+plotcoda = function( bdgraph.obj, thin = NULL, control = TRUE, main = NULL, ... )
 {
-	if( !is.null( x $ phat ) ) stop( "Function needs output of 'bdgraph' with option save.all = TRUE" ) 
+	if( !is.null( bdgraph.obj $ p_links ) ) stop( "It needs object of 'bdgraph' with option save.all = TRUE" ) 
 	
-	if( is.null( thin ) ) thin = ceiling( length( x $ allGraphs ) / 1000 )
+	if( is.null( thin ) ) thin = ceiling( length( bdgraph.obj $ all_graphs ) / 1000 )
 
-	sampleGraphs    = x $ sampleGraphs
-	p               = nrow( x $ lastGraph )
+	sample_graphs    = bdgraph.obj $ sample_graphs
+	p               = nrow( bdgraph.obj $ last_graph )
 	qp              = p * ( p - 1 ) / 2 
-	allWeights      = x $ allWeights
-	allGraphs       = x $ allGraphs
+	all_weights      = bdgraph.obj $ all_weights
+	all_graphs       = bdgraph.obj $ all_graphs
 
-	allG_new        = allGraphs[ c( thin * ( 1 : floor( length( allGraphs ) / thin ) ) ) ]
-	allWeights_new  = allWeights[ c( thin * ( 1 : floor( length( allWeights ) / thin ) ) ) ]
+	allG_new        = all_graphs[ c( thin * ( 1 : floor( length( all_graphs ) / thin ) ) ) ]
+	all_weights_new  = all_weights[ c( thin * ( 1 : floor( length( all_weights ) / thin ) ) ) ]
 	length_allG_new = length( allG_new )
 	result          = matrix( 0, qp, length_allG_new )
 	vec_result      = 0 * result[ , 1]
@@ -23,12 +23,12 @@ plotcoda = function( x, thin = NULL, main = NULL, links = TRUE, ... )
 		cat(mes, "\r")
 		flush.console()	
 
-		which_edge             = which( unlist( strsplit( as.character( sampleGraphs[ allG_new[g] ] ), "" ) ) == 1 )
-		vec_result[which_edge] = vec_result[which_edge] + allWeights_new[g]
-		result[ ,g]            = vec_result / sum( allWeights_new[ c( 1 : g ) ] )    	 
+		which_edge             = which( unlist( strsplit( as.character( sample_graphs[ allG_new[g] ] ), "" ) ) == 1 )
+		vec_result[which_edge] = vec_result[which_edge] + all_weights_new[g]
+		result[ ,g]            = vec_result / sum( all_weights_new[ c( 1 : g ) ] )    	 
 	}
 
-	if ( links )
+	if ( control )
 		if ( p > 15 )
 		{
 			randomLinks = sample( x = 1:qp, size = ( qp - 100 ), replace = FALSE )
